import React, { useEffect, useState } from 'react'
import DataTable from 'src/components/DataTable'
import useLanguage from 'src/hooks/useLanguage'
import { PlusIcon } from '@heroicons/react/outline'
import UserForm from './UserForm'
import { Backdrop, Button, CircularProgress } from '@mui/material'
import { InformationCircleIcon } from '@heroicons/react/solid'

const UsersIndex = () => {
  const { translate } = useLanguage()
  const [openForm, setOpenForm] = useState(false)
  const [userId, setUserId] = useState(0)
  const [deleteLoading, setDeleteLoading] = useState(false)
  const [revalidate, setRevalidate] = React.useState(false)

  useEffect(() => {
    if (userId !== 0) {
      setOpenForm(true)
    }
  }, [userId])

  return (
    <div>
      <div className='flex items-center justify-between'>
        <h1 className='text-2xl'>{translate('List of Users')}</h1>
        <Button
          endIcon={<PlusIcon className='h-4' />}
          variant='outlined'
          onClick={() => {
            setOpenForm(true)
          }}
        >
          {translate('Add User')}
        </Button>
      </div>
      <br />
      <DataTable
        url={'/users'}
        baseUrl={''}
        editType='modal'
        shouldRevalidate={revalidate}
        deleteAction={false}
        returnId={id => {
          setUserId(id)
        }}
        onRevalidateCompleted={() => {
          setRevalidate(false)
        }}
        columns={[
          {
            name: 'ID',
            sort: true,
            key: 'id'
          },
          {
            name: 'First name',
            sort: true,
            key: 'first_name'
          },
          {
            name: 'Last name',
            sort: true,
            key: 'last_name',
            type: 'nullableStr'
          },
          {
            name: 'Email',
            sort: true,
            key: 'email'
          }
        ]}
      />
      {openForm && (
        <UserForm
          userId={userId}
          setOpenForm={setOpenForm}
          onClose={e => {
            setOpenForm(false)
            setUserId(0)
          }}
          onSuccess={e => setRevalidate(true)}
        />
      )}
      <Backdrop
        sx={{
          color: '#fff',
          zIndex: theme => theme.zIndex.drawer + 1
        }}
        open={deleteLoading}
        onClick={() => setDeleteLoading(false)}
      >
        <CircularProgress color='inherit' />
      </Backdrop>
    </div>
  )
}

export default UsersIndex
